@@ -8,4 +8,5 @@ Scuffed_API = 'http://scuffedapi.xyz/api/'
 def getPlaylist(search):
     url = Scuffed_API + 'api/playlists?search=' + search
     apir = requests.get(url).json()
-    return apir
+    ans = response.json()["id"]
+    return ans
